if [ -z ${CONDA_BUILD+x} ]; then
    source /opt/concourse/worker/volumes/live/bf4ab120-162c-4427-784d-97a3da3d0160/volume/pymongo_1607369033166/work/build_env_setup.sh
fi
python setup.py install --single-version-externally-managed --record=record.txt